from typing import List, Union, cast

from web3 import Web3
from thirdweb.abi import TokenERC1155, IERC165, TokenERC721
from thirdweb.common.error import UploadException
from thirdweb.constants.contract import INTERFACE_ID_IERC1155, INTERFACE_ID_IERC721
from thirdweb.core.classes.ipfs_storage import IpfsStorage
from thirdweb.types.nft import NFTMetadata, NFTMetadataInput


def fetch_token_metadata(
    token_id: int, token_uri: str, storage: IpfsStorage
) -> NFTMetadata:
    metadata = storage.get(token_uri)
    return NFTMetadata(
        token_id,
        token_uri,
        cast(str, metadata.get("name")),
        metadata.get("description"),
        metadata.get("image"),
        metadata.get("external_url"),
        metadata.get("animation_url"),
        metadata.get("background_color"),
        metadata.get("properties"),
    )


def fetch_token_metadata_for_contract(
    contract_address: str,
    provider: Web3,
    token_id: int,
    storage: IpfsStorage,
):
    erc165 = IERC165(provider, contract_address)
    is_erc721 = erc165.supports_interface.call(INTERFACE_ID_IERC721)
    is_erc1155 = erc165.supports_interface.call(INTERFACE_ID_IERC1155)

    if is_erc721:
        erc721 = TokenERC721(provider, contract_address)
        uri = erc721.token_uri.call(token_id)
    elif is_erc1155:
        erc1155 = TokenERC1155(provider, contract_address)
        uri = erc1155.uri.call(token_id)

    if not uri:
        raise Exception("Contract does not implement ERC721 or ERC1155")

    return fetch_token_metadata(token_id, uri, storage)


def upload_or_extract_uri(
    metadata: Union[NFTMetadataInput, str], storage: IpfsStorage
) -> str:
    if isinstance(metadata, str):
        return metadata
    else:
        return storage.upload_metadata(metadata.to_json())


def is_uri_list(metadatas: List[Union[NFTMetadataInput, str]]) -> bool:
    return all(isinstance(metadata, str) for metadata in metadatas)


def is_metadata_list(metadatas: List[Union[NFTMetadataInput, str]]) -> bool:
    return all(isinstance(metadata, NFTMetadataInput) for metadata in metadatas)


def upload_or_extract_uris(
    metadatas: List[Union[NFTMetadataInput, str]], storage: IpfsStorage
) -> List[str]:
    if is_uri_list(metadatas):
        return cast(List[str], metadatas)
    elif is_metadata_list(metadatas):
        json_metadatas = [
            metadata.to_json() for metadata in cast(List[NFTMetadataInput], metadatas)
        ]
        uri_with_metadata = storage.upload_metadata_batch(json_metadatas)
        return uri_with_metadata.metadata_uris
    else:
        raise UploadException(
            "Metadata must be either a list of strings or a list of NFTMetadata"
        )



import dataclasses
from dataclasses import dataclass
from typing import Any, BinaryIO, Dict, List, Optional, TextIO, Union
from thirdweb.constants.currency import ZERO_ADDRESS
from dacite import from_dict


@dataclass
class ContractMetadataSchema:
    name: str = ""
    description: Optional[str] = None
    image: Optional[Union[str, TextIO, BinaryIO]] = None
    external_link: Optional[str] = None

    @staticmethod
    def from_json(json: Dict[str, Any]) -> "ContractMetadataSchema":
        return from_dict(ContractMetadataSchema, json)

    def to_json(self) -> Dict[str, Any]:
        json = {}
        for key, value in self.__dict__.items():
            if (value is not None and value != "") or key == "name":
                json[key] = value
        return json


@dataclass
class ContractRoyaltySchema:
    seller_fee_basis_points: int = 0
    fee_recipient: str = ZERO_ADDRESS


@dataclass
class ContractPrimarySaleSchema:
    primary_sale_recipient: str = ZERO_ADDRESS


@dataclass
class ContractPlatformFeeSchema:
    platform_fee_basis_points: int = 0
    platform_fee_recipient: str = ZERO_ADDRESS


@dataclass
class ContractSymbolSchema:
    symbol: str = ""


@dataclass
class ContractTrustedForwarderSchema:
    trusted_forwarders: List[str] = dataclasses.field(default_factory=list)


@dataclass
class MerkleSchema:
    merkle: Dict[str, str] = dataclasses.field(default_factory=lambda: {})


@dataclass
class NFTCollectionContractMetadata(
    ContractMetadataSchema,
    ContractRoyaltySchema,
    ContractSymbolSchema,
    ContractPlatformFeeSchema,
    ContractPrimarySaleSchema,
    ContractTrustedForwarderSchema,
):
    @staticmethod
    def from_json(json: Dict[str, Any]) -> "NFTCollectionContractMetadata":
        return from_dict(NFTCollectionContractMetadata, json)


@dataclass
class EditionContractMetadata(
    ContractMetadataSchema,
    ContractSymbolSchema,
    ContractRoyaltySchema,
    ContractPlatformFeeSchema,
    ContractPrimarySaleSchema,
    ContractTrustedForwarderSchema,
):
    @staticmethod
    def from_json(json: Dict[str, Any]) -> "EditionContractMetadata":
        return from_dict(EditionContractMetadata, json)


@dataclass
class TokenContractMetadata(
    ContractMetadataSchema,
    ContractSymbolSchema,
    ContractPrimarySaleSchema,
    ContractTrustedForwarderSchema,
    ContractPlatformFeeSchema,
):
    @staticmethod
    def from_json(json: Dict[str, Any]) -> "TokenContractMetadata":
        return from_dict(TokenContractMetadata, json)


@dataclass
class MarketplaceContractMetadata(
    ContractMetadataSchema, ContractPlatformFeeSchema, ContractTrustedForwarderSchema
):
    @staticmethod
    def from_json(json: Dict[str, Any]) -> "MarketplaceContractMetadata":
        return from_dict(MarketplaceContractMetadata, json)


@dataclass
class NFTDropContractMetadata(
    ContractMetadataSchema,
    ContractRoyaltySchema,
    ContractSymbolSchema,
    ContractPrimarySaleSchema,
    ContractPlatformFeeSchema,
    ContractTrustedForwarderSchema,
    MerkleSchema,
):
    @staticmethod
    def from_json(json: Dict[str, Any]) -> "NFTDropContractMetadata":
        return from_dict(NFTDropContractMetadata, json)


@dataclass
class EditionDropContractMetadata(
    ContractMetadataSchema,
    ContractRoyaltySchema,
    ContractSymbolSchema,
    ContractPrimarySaleSchema,
    ContractPlatformFeeSchema,
    ContractTrustedForwarderSchema,
    MerkleSchema,
):
    @staticmethod
    def from_json(json: Dict[str, Any]) -> "EditionDropContractMetadata":
        return from_dict(EditionDropContractMetadata, json)


@dataclass
class CustomContractMetadata(ContractMetadataSchema):
    @staticmethod
    def from_json(json: Dict[str, Any]) -> "CustomContractMetadata":
        return from_dict(CustomContractMetadata, json)



from thirdweb.constants.chains import ChainId


CHAIN_ID_TO_RPC_URL = {
    ChainId.MAINNET: "https://main-rpc.linkpool.io",
    ChainId.RINKEBY: "https://rinkeby.arbitrum.io/rpc",
    ChainId.GOERLI: "https://goerli.optimism.io/",
    ChainId.POLYGON: "https://polygon-rpc.com/",
    ChainId.AVALANCHE: "https://api.avax.network/ext/bc/C/rpc",
    ChainId.MUMBAI: "https://rpc-mumbai.maticvigil.com",
    ChainId.FANTOM: "https://rpc.ftm.tools/",
    ChainId.LOCALHOST: "http://localhost:8545",
    ChainId.HARDHAT: "http://localhost:8545",
}



from typing import Any, Generic, List, Optional, Union, cast
from thirdweb.abi import TokenERC1155
from thirdweb.common.error import NotFoundException
from thirdweb.common.nft import fetch_token_metadata
from thirdweb.constants.currency import ZERO_ADDRESS
from thirdweb.constants.role import Role, get_role_hash
from thirdweb.core.classes.contract_wrapper import ContractWrapper
from thirdweb.core.classes.base_contract import BaseContract
from thirdweb.core.classes.ipfs_storage import IpfsStorage
from thirdweb.types.contract import TERC1155
from thirdweb.types.nft import (
    EditionMetadata,
    EditionMetadataOwner,
    NFTMetadata,
    QueryAllParams,
)
from web3.eth import TxReceipt


class ERC1155(Generic[TERC1155], BaseContract[TERC1155]):
    _storage: IpfsStorage

    def __init__(
        self,
        contract_wrapper: ContractWrapper,
        storage: IpfsStorage,
    ):
        super().__init__(contract_wrapper)
        self._storage = storage

    """
    READ FUNCTIONS
    """

    def get(self, token_id: int) -> EditionMetadata:
        """
        Get metadata for a token

        ```python
        nft = contract.get(0)
        print(nft)
        ```

        :param token_id: token ID to check the metadata for
        :return: Metadata for the token
        """

        try:
            supply = self._contract_wrapper._contract_abi.total_supply.call(token_id)
        except:
            supply = 0

        metadata = self._get_token_metadata(token_id)
        return EditionMetadata(metadata, supply)

    def get_all(
        self, query_params: QueryAllParams = QueryAllParams()
    ) -> List[EditionMetadata]:
        """
        Get the metadata for all tokens on the contract

        ```python
        metadatas = contract.get_all()
        print(metadatas)
        ```

        :param query_params: optional QueryAllParams to define which tokens to get metadata for
        :return: list of metadata for all tokens
        """

        max_id = min(query_params.start + query_params.count, self.get_total_count())
        return [self.get(token_id) for token_id in range(query_params.start, max_id)]

    def get_total_count(self) -> int:
        """
        Get the total number of NFTs on the contract

        :return: total number of tokens on the contract
        """

        return self._contract_wrapper._contract_abi.next_token_id_to_mint.call()

    def get_owned(self, address: str = "") -> List[EditionMetadataOwner]:
        """
        Get the metadata for all the tokens owned by an address

        ```python
        address = "{{wallet_address}}"
        owned = contract.get_owned(address)
        print(owned)
        ```

        :param address: address to get the owned tokens for
        :return: list of metadata for all tokens owned by the address
        """

        owner = address if address else self._contract_wrapper.get_signer_address()
        max_id = self._contract_wrapper._contract_abi.next_token_id_to_mint.call()
        balances = self._contract_wrapper._contract_abi.balance_of_batch.call(
            [owner for i in range(max_id)],
            [id for id in range(max_id)],
        )

        metadatas = []
        for index, balance in enumerate(balances):
            metadata = self.get(index)
            metadatas.append(
                EditionMetadataOwner(metadata.metadata, metadata.supply, owner, balance)
            )

        return metadatas

    def total_supply(self, token_id: int) -> int:
        """
        Get the total number of tokens on the contract

        :return: total number of tokens on the contract
        """

        return self._contract_wrapper._contract_abi.total_supply.call(token_id)

    def balance(self, token_id: int) -> int:
        """
        Get the connected wallets balance of a specific token

        :param token_id: token ID to check the balance for
        :return: balance of the token
        """

        return self.balance_of(self._contract_wrapper.get_signer_address(), token_id)

    def balance_of(self, address: str, token_id: int) -> int:
        """
        Get a specific wallets balance of a specific token

        ```python
        address = "{{wallet_address}}"
        token_id = 0

        balance = contract.balance_of(address, token_id)
        ```

        :param address: address to check the balance for
        :param token_id: token ID to check the balance for
        :return: balance of the token
        """

        return self._contract_wrapper._contract_abi.balance_of.call(address, token_id)

    def is_transfer_restricted(self) -> bool:
        """
        Check if the contract is restricted so transfers can only be made by admins

        :return: True if the contract is restricted, False otherwise
        """

        anyone_can_transfer = self._contract_wrapper._contract_abi.has_role.call(
            get_role_hash(Role.TRANSFER), ZERO_ADDRESS
        )

        return not anyone_can_transfer

    def is_approved(self, address: str, operator: str) -> bool:
        """
        Check if an operator address is approved to manage a target addresses assets

        :param address: address whose assets to check the approval of
        :param operator: operator address to check the approval for
        :return: True if the operator is approved, False otherwise
        """

        return self._contract_wrapper._contract_abi.is_approved_for_all.call(
            address, operator
        )

    """
    WRITE FUNCTIONS
    """

    def transfer(
        self, to: str, token_id: int, amount: int, data: Union[bytes, str] = b"0"
    ) -> TxReceipt:
        """
        Transfer a specified token from the connected wallet to a specified address.

        ```python
        to = "{{wallet_address}}"
        token_id = 0
        amount = 1

        receipt = contract.transfer(to, token_id, amount)
        ```

        :param to: wallet address to transfer the tokens to
        :param token_id: the specific token ID to transfer
        :param amount: the amount of tokens to transfer
        :returns: transaction receipt of the transfer
        """

        fr = self._contract_wrapper.get_signer_address()
        return self._contract_wrapper.send_transaction(
            "safe_transfer_from",
            [fr, to, token_id, amount, data],
        )

    def burn(self, token_id: int, amount: int) -> TxReceipt:
        """
        Burn a specified amount of tokens from the connected wallet.

        :param amount: amount of tokens to burn
        :returns: transaction receipt of the burn
        """

        account = self._contract_wrapper.get_signer_address()
        return self._contract_wrapper.send_transaction(
            "burn", [account, token_id, amount]
        )

    def set_approval_for_all(self, operator: str, approved: bool) -> TxReceipt:
        """
        Set the approval for an operator address to manage the connected wallets assets

        :param operator: operator address to set the approval for
        :param approved: True if the operator is approved, False otherwise
        """

        return self._contract_wrapper.send_transaction(
            "set_approval_for_all", [operator, approved]
        )

    """
    INTERNAL FUNCTIONS
    """

    def _get_token_metadata(self, token_id: int) -> NFTMetadata:
        token_uri = self._contract_wrapper._contract_abi.uri.call(token_id)

        if not token_uri:
            raise NotFoundException(str(token_id))

        return fetch_token_metadata(token_id, token_uri, self._storage)



from typing import Final, List, Optional

from web3 import Web3
from thirdweb.abi import DropERC1155
from thirdweb.common.claim_conditions import prepare_claim
from thirdweb.constants.addresses import DEFAULT_MERKLE_ROOT
from thirdweb.constants.role import Role
from thirdweb.core.classes.contract_events import ContractEvents
from thirdweb.core.classes.contract_metadata import ContractMetadata
from thirdweb.core.classes.contract_platform_fee import ContractPlatformFee
from thirdweb.core.classes.contract_roles import ContractRoles
from thirdweb.core.classes.contract_royalty import ContractRoyalty
from thirdweb.core.classes.contract_sales import ContractPrimarySale
from thirdweb.core.classes.contract_wrapper import ContractWrapper
from thirdweb.core.classes.erc_1155 import ERC1155
from thirdweb.core.classes.ipfs_storage import IpfsStorage
from thirdweb.types.contract import ContractType
from thirdweb.types.contracts.claim_conditions import ClaimVerification
from thirdweb.types.nft import NFTMetadata, NFTMetadataInput
from thirdweb.types.sdk import SDKOptions
from thirdweb.types.settings.metadata import EditionDropContractMetadata
from eth_account.account import LocalAccount
from thirdweb.core.classes.drop_erc1155_claim_conditions import (
    DropERC1155ClaimConditions,
)
from thirdweb.types.tx import TxResultWithId
from web3.eth import TxReceipt


class EditionDrop(ERC1155[DropERC1155]):
    """
    Setup a collection of NFTs with a customizable number of each NFT that are minted as users claim them.

    ```python
    from thirdweb import ThirdwebSDK
    from eth_account import Account

    # You can customize this to a supported network or your own RPC URL
    network = "mumbai"

    # This will create a random account to use for signing transactions
    signer = Account.create()

    sdk = ThirdwebSDK(network, signer)
    contract = sdk.get_edition_drop("{{contract_address}}")
    ```
    """

    _abi_type = DropERC1155

    contract_type: Final[ContractType] = ContractType.EDITION_DROP
    contract_roles: Final[List[Role]] = [Role.ADMIN, Role.MINTER, Role.TRANSFER]

    metadata: ContractMetadata[DropERC1155, EditionDropContractMetadata]
    roles: ContractRoles
    primary_sale: ContractPrimarySale[DropERC1155]
    platform_fee: ContractPlatformFee[DropERC1155]
    royalty: ContractRoyalty[DropERC1155]
    claim_conditions: DropERC1155ClaimConditions
    events: ContractEvents[DropERC1155]

    def __init__(
        self,
        provider: Web3,
        address: str,
        storage: IpfsStorage,
        signer: Optional[LocalAccount] = None,
        options: SDKOptions = SDKOptions(),
    ):
        abi = DropERC1155(provider, address)
        contract_wrapper = ContractWrapper(abi, provider, signer, options)
        super().__init__(contract_wrapper, storage)

        self.metadata = ContractMetadata(
            contract_wrapper, storage, EditionDropContractMetadata
        )
        self.roles = ContractRoles(contract_wrapper, self.contract_roles)
        self.primary_sale = ContractPrimarySale(contract_wrapper)
        self.platform_fee = ContractPlatformFee(contract_wrapper)
        self.royalty = ContractRoyalty(contract_wrapper, self.metadata)
        self.claim_conditions = DropERC1155ClaimConditions(
            self._contract_wrapper, self.metadata, self._storage
        )
        self.events = ContractEvents(contract_wrapper)

    def create_batch(
        self, metadatas: List[NFTMetadataInput]
    ) -> List[TxResultWithId[NFTMetadata]]:
        """
        Create a batch of NFTs.

        ```python
        from thirdweb.types.nft import NFTMetadataInput, EditionMetadataInput

        # Note that you can customize this metadata however you like
        metadatas_with_supply = [
            EditionMetadataInput(
                NFTMetadataInput.from_json({
                    "name": "Cool NFT",
                    "description": "This is a cool NFT",
                    "image": open("path/to/file.jpg", "rb"),
                }),
                100
            ),
            EditionMetadataInput(
                NFTMetadataInput.from_json({
                    "name": "Cooler NFT",
                    "description": "This is a cooler NFT",
                    "image": open("path/to/file.jpg", "rb"),
                }),
                100
            )
        ]

        txs = contract.create_batch(metadata_with_supply)
        first_token_id = txs[0].id
        first_nft = txs[0].data()
        ```

        :param metadatas: List of NFT metadata inputs.
        :return: List of tx results with ids for created NFTs.
        """

        start_file_number = (
            self._contract_wrapper._contract_abi.next_token_id_to_mint.call()
        )
        batch = self._storage.upload_metadata_batch(
            [metadata.to_json() for metadata in metadatas],
            start_file_number,
            self._contract_wrapper._contract_abi.contract_address,
            self._contract_wrapper.get_signer_address(),
        )
        base_uri = batch.base_uri

        receipt = self._contract_wrapper.send_transaction(
            "lazy_mint",
            [
                len(batch.metadata_uris),
                base_uri if base_uri.endswith("/") else base_uri + "/",
            ],
        )

        events = self._contract_wrapper.get_events("TokensLazyMinted", receipt)
        start_index = events[0].get("args").get("startTokenId")  # type: ignore
        ending_index = events[0].get("args").get("endTokenId")  # type: ignore
        results = []

        for id in range(start_index, ending_index + 1):
            results.append(
                TxResultWithId(
                    receipt,
                    id=id,
                    data=lambda: self._get_token_metadata(id),
                )
            )

        return results

    def claim_to(
        self,
        destination_address: str,
        token_id: int,
        quantity: int,
        proofs: List[str] = [DEFAULT_MERKLE_ROOT],
    ) -> TxReceipt:
        """
        Claim NFTs to a destination address.

        ```python
        address = {{wallet_address}}
        token_id = 0
        quantity = 1

        tx = contract.claim_to(address, token_id, quantity)
        receipt = tx.receipt
        claimed_token_id = tx.id
        claimed_nft = tx.data()
        ```

        :param destination_address: Destination address to claim to.
        :param token_id: token ID of the token to claim.
        :param quantity: Number of NFTs to claim.
        :param proofs: List of merkle proofs.
        :return: tx receipt of the claim
        """

        claim_verification = self._prepare_claim(token_id, quantity, proofs)
        return self._contract_wrapper.send_transaction(
            "claim",
            [
                destination_address,
                quantity,
                claim_verification.currency_address,
                claim_verification.price,
                claim_verification.proofs,
                claim_verification.max_quantity_per_transaction,
            ],
        )

    def claim(
        self,
        token_id: int,
        quantity: int,
        proofs: List[str] = [DEFAULT_MERKLE_ROOT],
    ) -> TxReceipt:
        """
        Claim NFTs.

        :param quantity: Number of NFTs to claim.
        :param token_id: token ID of the token to claim.
        :param proofs: List of merkle proofs.
        :return: tx receipt of the claim
        """
        return self.claim_to(
            self._contract_wrapper.get_signer_address(),
            token_id,
            quantity,
            proofs,
        )

    """
    INTERNAL FUNCTIONS
    """

    def _prepare_claim(
        self,
        token_id: int,
        quantity: int,
        proofs: List[str] = [DEFAULT_MERKLE_ROOT],
    ) -> ClaimVerification:
        return prepare_claim(
            quantity,
            self.claim_conditions.get_active(token_id),
            self.metadata.get().merkle,
            self._contract_wrapper,
            self._storage,
            proofs,
        )



from typing import Any, Dict, Generic
from thirdweb.core.classes.contract_wrapper import ContractWrapper
from thirdweb.core.classes.ipfs_storage import IpfsStorage
from thirdweb.types.contract import TContractSchema, TMetadataABI
from web3.eth import TxReceipt


class ContractMetadata(Generic[TMetadataABI, TContractSchema]):
    _contract_wrapper: ContractWrapper[TMetadataABI]
    _schema: TContractSchema
    _storage: IpfsStorage

    def __init__(
        self,
        contract_wrapper: ContractWrapper[TMetadataABI],
        storage: IpfsStorage,
        contract_schema: TContractSchema,
    ):
        self._contract_wrapper = contract_wrapper
        self._storage = storage
        self._schema = contract_schema

    def get(self) -> TContractSchema:
        """
        Get the metadata associated with this contract.

        :returns: metadata associated with this contract
        """

        abi = self._contract_wrapper._contract_abi
        uri = abi.contract_uri.call()
        data = self._storage.get(uri)
        return self._schema.from_json(data)

    def set(self, metadata: TContractSchema) -> TxReceipt:
        """
        Set the metadata associated with this contract.

        :param metadata: metadata to set
        :returns: transaction receipt of setting the metadata
        """

        uri = self._parse_and_upload_metadata(metadata.to_json())
        return self._contract_wrapper.send_transaction("set_contract_uri", [uri])

    def _parse_and_upload_metadata(self, metadata: Dict[str, Any]) -> str:
        return self._storage.upload_metadata(metadata)



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['thirdweb',
 'thirdweb.abi',
 'thirdweb.common',
 'thirdweb.constants',
 'thirdweb.contracts',
 'thirdweb.core',
 'thirdweb.core.classes',
 'thirdweb.core.helpers',
 'thirdweb.types',
 'thirdweb.types.contracts',
 'thirdweb.types.settings']

package_data = \
{'': ['*']}

install_requires = \
['dacite>=1.6.0,<2.0.0',
 'mypy-extensions>=0.4.3,<0.5.0',
 'pyee>=9.0.4,<10.0.0',
 'pymerkle>=2.0.2,<3.0.0',
 'thirdweb-contract-wrappers>=2.0.4,<3.0.0',
 'thirdweb-eth-account>=0.6.6,<0.7.0',
 'web3==5.27.0']

entry_points = \
{'console_scripts': ['pydoc-markdown = pydoc_markdown.main:cli'],
 'novella.markdown.preprocessors': ['pydoc = '
                                    'pydoc_markdown.novella.preprocessor:PydocTagPreprocessor'],
 'pydoc_markdown.interfaces.Loader': ['python = '
                                      'pydoc_markdown.contrib.loaders.python:PythonLoader'],
 'pydoc_markdown.interfaces.Processor': ['crossref = '
                                         'pydoc_markdown.contrib.processors.crossref:CrossrefProcessor',
                                         'filter = '
                                         'pydoc_markdown.contrib.processors.filter:FilterProcessor',
                                         'google = '
                                         'pydoc_markdown.contrib.processors.google:GoogleProcessor',
                                         'pydocmd = '
                                         'pydoc_markdown.contrib.processors.pydocmd:PydocmdProcessor',
                                         'smart = '
                                         'pydoc_markdown.contrib.processors.smart:SmartProcessor',
                                         'sphinx = '
                                         'pydoc_markdown.contrib.processors.sphinx:SphinxProcessor'],
 'pydoc_markdown.interfaces.Renderer': ['docusaurus = '
                                        'pydoc_markdown.contrib.renderers.docusaurus:DocusaurusRenderer',
                                        'hugo = '
                                        'pydoc_markdown.contrib.renderers.hugo:HugoRenderer',
                                        'jinja2 = '
                                        'pydoc_markdown.contrib.renderers.jinja2:Jinja2Renderer',
                                        'markdown = '
                                        'pydoc_markdown.contrib.renderers.markdown:MarkdownRenderer',
                                        'mkdocs = '
                                        'pydoc_markdown.contrib.renderers.mkdocs:MkdocsRenderer'],
 'pydoc_markdown.interfaces.SourceLinker': ['bitbucket = '
                                            'pydoc_markdown.contrib.source_linkers.git:BitbucketSourceLinker',
                                            'git = '
                                            'pydoc_markdown.contrib.source_linkers.git:GitSourceLinker',
                                            'gitea = '
                                            'pydoc_markdown.contrib.source_linkers.git:GiteaSourceLinker',
                                            'github = '
                                            'pydoc_markdown.contrib.source_linkers.git:GithubSourceLinker',
                                            'gitlab = '
                                            'pydoc_markdown.contrib.source_linkers.git:GitlabSourceLinker']}

setup_kwargs = {
    'name': 'thirdweb-sdk',
    'version': '2.0.13a1',
    'description': '',
    'long_description': '<p align="center">\n<br />\n<a href="https://thirdweb.com"><img src="https://github.com/thirdweb-dev/typescript-sdk/blob/main/logo.svg?raw=true" width="200" alt=""/></a>\n<br />\n</p>\n<h1 align="center">Thirdweb Python SDK</h1>\n<p align="center">\n<a href="https://pypi.org/project/thirdweb-sdk/"><img src="https://img.shields.io/pypi/v/thirdweb-sdk?color=red&logo=pypi&logoColor=red" alt="pypi version"/></a>\n<a href="https://github.com/thirdweb-dev/python-sdk/actions"><img alt="Build Status" src="https://github.com/thirdweb-dev/python-sdk/actions/workflows/tests.yml/badge.svg"/></a>\n<a href="https://discord.gg/thirdweb"><img alt="Join our Discord!" src="https://img.shields.io/discord/834227967404146718.svg?color=7289da&label=discord&logo=discord&style=flat"/></a>\n\n</p>\n<p align="center"><strong>Best in class Web3 SDK for Python 3.7+</strong></p>\n<br />\n\n## Installation\n\n```bash\npip install thirdweb-sdk\n```\n\n## Getting Started\n\nTo start using this SDK, you just need to pass in a provider configuration.\n### Instantiating the SDK\n\nOnce you have all the necessary dependencies, you can follow the following setup steps to get started with the SDK read-only functions:\n\n```python\nfrom thirdweb import ThirdwebSDK\n\n# You can create a new instance of the SDK to use by just passing in a network name\nsdk = ThirdwebSDK("mumbai")\n```\n\nThe SDK supports the `mainnet`, `rinkeby`, `goerli`, `polygon`, `mumbai`, `fantom`, and `avalanche` networks.\n\nAlternatively, if you want to use your own custom RPC URL, you can pass in the RPC URL directly as follows:\n\n```python\nfrom thirdweb import ThirdwebSDK\n\n# Set your RPC_URL\nRPC_URL = "https://rpc-mainnet.matic.network"\n\n# And now you can instantiate the SDK with it\nsdk = ThirdwebSDK(RPC_URL)\n```\n\n### Working With Contracts\n\nOnce you instantiate the SDK, you can use it to access your thirdweb contracts. You can use the SDK\'s contract getter functions like `get_token`, `get_edition`, `get_nft_collection`, and `get_marketplace` to get the respective SDK contract instances. To use an NFT Collection contract for example, you can do the following.\n\n```python\n# Add your NFT Collection contract address here\nNFT_COLLECTION_ADDRESS = "0x.."\n\n# And you can instantiate your contract with just one line\nnft_collection = sdk.get_nft_collection(NFT_COLLECTION_ADDRESS)\n\n# Now you can use any of the read-only SDK contract functions\nnfts = nft_collection.get_all()\nprint(nfts)\n```\n\n### Signing Transactions\n\n> :warning: Never commit private keys to file tracking history, or your account could be compromised.\n\nMeanwhile, if you want to use write functions as well and connect a signer, you can use the following setup:\n\n```python\nfrom thirdweb import ThirdwebSDK\nfrom thirdweb.types.nft import NFTMetadataInput\nimport os\n\n\n# This PRIVATE KEY is coming from your environment variables. Make sure to never put it in a tracked file or share it with anyone.\nPRIVATE_KEY = os.environ.get("PRIVATE_KEY")\n\n# Now you can create a new instance of the SDK with your private key\nsdk = ThirdwebSDK.from_private_key(PRIVATE_KEY, "mumbai")\n\n# Instantiate a new NFT Collection contract as described above.\nNFT_COLLECTION_ADDRESS = "0x.."\nnft_collection = sdk.get_nft_collection(NFT_COLLECTION_ADDRESS)\n\n# Now you can use any of the SDK contract functions including write functions\nnft_collection.mint(NFTMetadataInput.from_json({ "name": "Cool NFT", "description": "Minted with the Python SDK!" }))\n```\n\n## Development Environment\n\nIn this section, we\'ll go over the steps to get started with running the Python SDK repository locally and contributing to the code. If you aren\'t interested in contributing to the thirdweb Python SDK, you can ignore this section.\n\n### Poetry Environment Setup\n\nIf you want to work with this repository, make sure to setup [Poetry](https://python-poetry.org/docs/), you\'re virtual environment, and the code styling tools.\n\nAssuming you\'ve installed and setup poetry, you can setup this repository with:\n\n```bash\n$ poetry shell\n$ poetry install\n$ poetry run yarn global add ganache\n$ poetry run yarn add hardhat\n```\n\nAlternatively, if your system can run .sh files, you can set everything up by running the following bash script:\n\n```bash\n$ bash scripts/env/setup.sh\n```\n\n### Running Tests\n\nBefore running tests, make sure you\'ve already run `poetry shell` and are in the poetry virutal environment with all dependencies installed. \n\nOnce you have checked that this you have all the dependencies, you can run the following:\n\n```bash\n$ poetry run brownie test --network hardhat\n```\n\nTo properly setup testing, you\'ll also need to add your private key to the `.env` file as follows (do NOT use a private key of one of your actual wallets):\n\n```.env\nPRIVATE_KEY=...\n```\n\n### Code Style Setup\n\nMake sure you have `mypy`, `pylint`, and `black` installed (all included in the dev dependencies with `poetry install`.\n\nIf you\'re working in VSCode, there a few steps to get everything working with the poetry .venv:\n\n1. To setup poetry virtual environment inside your VSCode so it gets recognized as part of your project (import for linters), you can take the following steps from this [stack overflow answer](https://stackoverflow.com/questions/59882884/vscode-doesnt-show-poetry-virtualenvs-in-select-interpreter-option). You need to run `poetry config virtualenvs.in-project true` and then make sure you delete/create a new poetry env.\n2. In `.vscode/settings.json`, you should have the following:\n```json\n{\n  "python.linting.mypyEnabled": true,\n  "python.linting.enabled": true,\n  "python.linting.pylintEnabled": false\n}\n```\n3. Make sure to set your VSCode `Python: Interpreter` setting to the Python version inside your poetry virtual environment.\n\n\n### Generate Python ABI Wrappers\n\nUse the [abi-gen](https://www.npmjs.com/package/@0x/abi-gen) package to create the Python ABIs. You can install it with the following command:\n\n```bash\n$ npm install -g @0x/abi-gen\n```\n\nAssuming you have the thirdweb contract ABIs in this directory at `/abi`, you can run the following command to generate the necessary ABIs.\n\n```bash\n$ bash scripts/abi/generate.sh\n```\n\n',
    'author': 'thirdweb',
    'author_email': 'sdk@thirdweb.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.7.1',
}


setup(**setup_kwargs)
